@@ -1,4 +1,5 @@
 import spur
+import spur.ssh
 
 
 _fields = [
@@ -38,5 +39,6 @@ class SshConfig(object):
             hostname=self.hostname,
             port=self.port,
             username=self.user,
-            password=self.password
+            password=self.password,
+            missing_host_key=spur.ssh.MissingHostKey.accept,
         )
